# setup.py
from setuptools import setup, find_packages

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name="pdf2img2pdf",
    version="1.0.0",
    author="siwen.huang",
    author_email="594047189@qq.com",
    description="A tool to convert PDF to images and back to PDF",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/yourusername/pdf2img2pdf",
    packages=find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.6",
    install_requires=[
        "pdf2image",
        "img2pdf",
    ],
    entry_points={
        "console_scripts": [
            "pdf2img2pdf=pdf2img2pdf.pdf2img2pdf:main",  # 命令行入口
        ],
    },
)